/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef FSGJT_JOB_H
#define FSGJT_JOB_H

#include <fsgjt.h>

/* Constant to use for the type of this JTAPI object */
#define FSGJT_JOB_OBJECT_TYPE           "FSGJT_JOB"

/************************************************************
 * Job attributes
 ***********************************************************/
#define FSGJT_JOB_COMMENT                    "job-comment"
#define FSGJT_JOB_COPIES                     "job-copies"
#define FSGJT_JOB_DESTINATIONS               "job-destinations"
#define FSGJT_JOB_DOCUMENT_FORMAT            "job-document-format"
#define FSGJT_JOB_MEDIA                      "job-media"
#define FSGJT_JOB_NAME                       "job-name"
#define FSGJT_JOB_ROTATION                   "job-rotation"
#define FSGJT_JOB_PRINT_QUALITY              "job-print-quality"
#define FSGJT_JOB_SIDES                      "job-sides"
#define FSGJT_JOB_STITCHING                  "job-stitching"

/************************************************************
 * fsgjtNewJob - Creates a Job containing the provided 
 * Document.
 *
 * param fsgjt_object_t* job - Pointer to job to be created
 * param fsgjt_object_t document - Document to be contained 
 *      in this job
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJob(
               fsgjt_object_t* job, 
               fsgjt_object_t document);

/************************************************************
 * fsgjtGetDocuments - Get the documents that this job 
 * contains.
 *
 * param fsgjt_object_t job - Job to get the documents from
 *
 * return fsgjt_object_t* - List of this job's documents
 ***********************************************************/
fsgjt_object_t* fsgjtGetDocuments(fsgjt_object_t job);

#endif /* FSGJT_JOB_H */