/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef FSGJT_JOB_TICKET_INFO_H
#define FSGJT_JOB_TICKET_INFO_H

#include <stdio.h>
#include <fsgjt.h>

/* Defined constant to use for the type of this JTAPI object */
#define FSGJT_JOB_TICKET_INFO_OBJECT_TYPE    "FSGJT_JOB_TICKET"

/************************************************************
 * Job Ticket Info attributes
 ***********************************************************/
#define FSGJT_JT_API_VERSION     "jt-api-version"
#define FSGJT_JT_COMMENT         "jt-comment"
#define FSGJT_JT_LENGTH_UNIT     "jt-length-unit"
#define FSGJT_JT_TYPE            "jt-type-and-version"

/************************************************************
 * Other constants
 ***********************************************************/
#define FSGJT_API_VERSION        "alpha"

/************************************************************
 * fsgjtNewJobTicketInfoFromURI - Creates a JobTicketInfo 
 * object from the job ticket file at the provided URI. Other 
 * JTAPI objects are also created based on the information in
 * the job ticket file.
 *
 * param fsgjt_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param char* uri - URI where job ticket file resides.
 *
 * return fsgjt_status_t
 ***********************************************************/
fsgjt_status_t fsgjtNewJobTicketInfoFromURL(
               fsgjt_object_t* jobTicketInfo,
               char* uri);

/************************************************************
 * fsgjtNewJobTicketInfoFromStream - Creates a JobTicketInfo 
 * object from the provided stream that contains a job 
 * ticket. Other JTAPI objects are also created based on the 
 * information in the job ticket file.
 *
 * param fsgjt_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param FILE* stream - Stream that contains a job ticket
 *
 * return fsgjt_status_t
 ***********************************************************/
fsgjt_status_t fsgjtNewJobTicketInfoFromStream(
               fsgjt_object_t* jobTicketInfo,
               FILE* stream);

/************************************************************
 * fsgjtNewJobTicketInfoFromJob - Creates a JobTicketInfo 
 * object using the provided Job object. Used when a new job 
 * ticket is being created. The Job object must be created 
 * first.
 *
 * param fsgjt_object_t* jobTicketInfo - Pointer to the new 
 *      JobTicketInfo
 * param fsgjt_object_t job - Job object for the 
 *      JobTicketInfo to be created
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJobTicketInfoFromJob(
               fsgjt_object_t* jobTicketInfo,
               fsgjt_object_t job);

/************************************************************
 * fsgjtGetJob - Get the Job that this JobTicketInfo 
 * contains.
 *
 * param fsgjt_object_t job - JobTicketInfo to get the job 
 *      from
 *
 * return fsgjt_object_t - This JobTicketInfo's Job
 ***********************************************************/
fsgjt_object_t fsgjtGetJob(fsgjt_object_t jobTicketInfo);

/************************************************************
 * fsgjtWriteJobTicketStream - Writes a job ticket to the 
 * provided stream.
 *
 * param fsgjt_object_t jobTicketInfo - JobTicketInfo from 
 *      which the job ticket is to be written
 * param FILE* stream - Stream to write the job ticket to
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtWriteJobTicketStream(
               fsgjt_object_t jobTicketInfo,
               FILE* stream);

/************************************************************
 * fsgjtWriteJobTicketURI - Wrtes a job ticket at the 
 * provided URI.
 *
 * param fsgjt_object_t jobTicketInfo - JobTicketInfo from 
 *      which the job ticket is to be written
 * param char* uri - URI of the job ticket that is to be 
 *      created from the JobTicketInfo. 
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtWriteJobTicketURI(
               fsgjt_object_t jobTicketInfo,
               char* uri);

#endif /* FSGJT_JOB_TICKET_INFO_H */
